@@ -1,12 +1,19 @@
-from flask_classful import FlaskView
+import json
+
+from notebuild.tool.fastapi import add_api_routes, api_route
+from notecoin.database.connect import RedisConnect
+from notecoin.server.market_coins import MarketCoins
 from notecoin.strategy.domain import OkexCoin
-from notecoin.strategy.utils import account_api, market_api
+from notecoin.strategy.utils import account_api
 
 
-class Strategy1(FlaskView):
-    def __init__(self):
+class AutoSeller(RedisConnect):
+    def __init__(self, market=None, *args, **kwargs):
         self.usdt = 0
         self.coin_map = {}
+        self.market = market or MarketCoins()
+        super(AutoSeller, self).__init__(*args, **kwargs)
+        add_api_routes(self)
 
     def load_account(self):
         data = account_api.get_account().data[0]
@@ -20,7 +27,7 @@ class Strategy1(FlaskView):
                 self.coin_map[coin.coin_id] = coin
 
     def update_price(self):
-        data = market_api.get_tickers('SPOT').data
+        data = json.loads(self.market.get_value().to_json(orient="records"))
         data_map = dict([(cin['instId'], cin['last']) for cin in data])
         for coin in self.coin_map.values():
             coin.price = float(data_map[coin.coin_id])
@@ -31,9 +38,14 @@ class Strategy1(FlaskView):
             "coins": [coin.to_json() for coin in self.coin_map.values()]
         }
 
-    def update(self):
+    @api_route("/update")
+    def update_value(self, suffix=""):
         self.load_account()
         self.update_price()
         for coin in self.coin_map.values():
             coin.watch()
         return self.to_json()
+
+
+seller = AutoSeller()
+print(seller.update_value())
